@@ -1,6 +1,6 @@
 
 
-class ComponentSpecificParametersEnum():
+class ComponentSpecificParametersEnum:
     __LOW = "low"
     __HIGH = "high"
     __K = "k"
@@ -22,6 +22,44 @@ class ComponentSpecificParametersEnum():
     __AZDOCK_DOCKERSCRIPTPATH = "docker_script_path"
     __AZDOCK_ENVPATH = "environment_path"
     __AZDOCK_DEBUG = "debug"
+    #######################
+
+    __RAT_PK_PROPERTY = "rat_pk_property"
+    __CLAB_TOP_20_VALUE = "clab_top_20_value"
+    __ION_CLASS = "Ion class"
+    __CONTAINER_TYPE = "container_type"
+
+    @property
+    def CONTAINER_TYPE(self):
+        return self.__CONTAINER_TYPE
+
+    @CONTAINER_TYPE.setter
+    def CONTAINER_TYPE(self, value):
+        raise ValueError("Do not assign value to a ComponentSpecificParametersEnum field")
+
+    @property
+    def ION_CLASS(self):
+        return self.__ION_CLASS
+
+    @ION_CLASS.setter
+    def ION_CLASS(self, value):
+        raise ValueError("Do not assign value to a ComponentSpecificParametersEnum field")
+
+    @property
+    def CLAB_TOP_20_VALUE(self):
+        return self.__CLAB_TOP_20_VALUE
+
+    @CLAB_TOP_20_VALUE.setter
+    def CLAB_TOP_20_VALUE(self, value):
+        raise ValueError("Do not assign value to a ComponentSpecificParametersEnum field")
+
+    @property
+    def RAT_PK_PROPERTY(self):
+        return self.__RAT_PK_PROPERTY
+
+    @RAT_PK_PROPERTY.setter
+    def RAT_PK_PROPERTY(self, value):
+        raise ValueError("Do not assign value to a ComponentSpecificParametersEnum field")
 
     @property
     def AZDOCK_DEBUG(self):
