@@ -9,13 +9,14 @@ from reinvent_scoring.scoring.score_transformations import TransformationFactory
 from reinvent_scoring.scoring.enums import TransformationTypeEnum
 from reinvent_chemistry.phys_chem_descriptors import PhysChemDescriptors
 
+
 class BasePhysChemComponent(BaseScoreComponent):
     def __init__(self, parameters: ComponentParameters):
         super().__init__(parameters)
         self._transformation_function = self._assign_transformation(self.parameters.specific_parameters)
         self._phys_chem_descriptors = PhysChemDescriptors()
 
-    def calculate_score(self, molecules: List) -> ComponentSummary:
+    def calculate_score(self, molecules: List, step=-1) -> ComponentSummary:
         score, raw_score = self._calculate_score(molecules)
         score_summary = ComponentSummary(total_score=score, parameters=self.parameters, raw_score=raw_score)
         return score_summary
